@@ -27,7 +27,7 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <tinyxml.h>
+#include <tinyxml2.h>
 
 /* TODO: Figure out why this is required here */
 #define I_KNOW_RARIAN_0_8_IS_UNSTABLE
@@ -52,8 +52,8 @@ enum ElemType {
 
 static char *omf_process_category(char *omf_cat);
 
-static void get_attribute(TiXmlElement *elem, ElemType e, RrnReg *reg) {
-    TiXmlAttribute *pAttrib = elem->FirstAttribute();
+static void get_attribute(tinyxml2::XMLElement *elem, ElemType e, RrnReg *reg) {
+    const tinyxml2::XMLAttribute *pAttrib = elem->FirstAttribute();
 
     while (pAttrib != NULL) {
         if (e == REG_URI && !strcmp(pAttrib->Name(), "url")) {
@@ -80,7 +80,7 @@ static void get_attribute(TiXmlElement *elem, ElemType e, RrnReg *reg) {
     }
 }
 
-static void get_text(TiXmlNode *pElement, ElemType e, RrnReg *reg) {
+static void get_text(tinyxml2::XMLNode *pElement, ElemType e, RrnReg *reg) {
     if (!pElement) {
         if (e == REG_NAME) {
             reg->name = strdup(" ");
@@ -96,48 +96,41 @@ static void get_text(TiXmlNode *pElement, ElemType e, RrnReg *reg) {
     }
 }
 
-static int process_node(TiXmlNode *pParent, RrnReg *reg) {
-    TiXmlNode *pChild;
-    TiXmlText *pText;
-    int t = pParent->Type();
+static int process_node(tinyxml2::XMLNode *pParent, RrnReg *reg) {
+    tinyxml2::XMLNode *pChild;
+    tinyxml2::XMLText *pText;
     int num;
     ElemType e;
 
-    switch (t) {
-        case TiXmlNode::TINYXML_DOCUMENT:
-            break;
-
-        case TiXmlNode::TINYXML_ELEMENT:
-            if (!strcmp(pParent->Value(), "omf")) {
-                am_parsing = true;
-            } else if (!am_parsing) {
-                return 1;
-            }
-            if (!strcmp(pParent->Value(), "title")) {
-                e = REG_NAME;
-                get_text(pParent->FirstChild(), e, reg);
-            } else if (!strcmp(pParent->Value(), "description")) {
-                e = REG_DESC;
-                get_text(pParent->FirstChild(), e, reg);
-            } else if (!strcmp(pParent->Value(), "identifier")) {
-                e = REG_URI;
-                get_attribute(pParent->ToElement(), e, reg);
-            } else if (!strcmp(pParent->Value(), "language")) {
-                e = REG_LANG;
-                get_attribute(pParent->ToElement(), e, reg);
-            } else if (!strcmp(pParent->Value(), "relation")) {
-                e = REG_SERIES;
-                get_attribute(pParent->ToElement(), e, reg);
-            } else if (!strcmp(pParent->Value(), "format")) {
-                e = REG_TYPE;
-                get_attribute(pParent->ToElement(), e, reg);
-            } else if (!strcmp(pParent->Value(), "subject")) {
-                e = REG_CATEGORIES;
-                get_attribute(pParent->ToElement(), e, reg);
-            }
-            break;
-        default:
-            break;
+    if ((pParent->ToDocument() == nullptr) &&
+        (pParent->ToElement() != nullptr)) {
+        if (!strcmp(pParent->Value(), "omf")) {
+            am_parsing = true;
+        } else if (!am_parsing) {
+            return 1;
+        }
+        if (!strcmp(pParent->Value(), "title")) {
+            e = REG_NAME;
+            get_text(pParent->FirstChild(), e, reg);
+        } else if (!strcmp(pParent->Value(), "description")) {
+            e = REG_DESC;
+            get_text(pParent->FirstChild(), e, reg);
+        } else if (!strcmp(pParent->Value(), "identifier")) {
+            e = REG_URI;
+            get_attribute(pParent->ToElement(), e, reg);
+        } else if (!strcmp(pParent->Value(), "language")) {
+            e = REG_LANG;
+            get_attribute(pParent->ToElement(), e, reg);
+        } else if (!strcmp(pParent->Value(), "relation")) {
+            e = REG_SERIES;
+            get_attribute(pParent->ToElement(), e, reg);
+        } else if (!strcmp(pParent->Value(), "format")) {
+            e = REG_TYPE;
+            get_attribute(pParent->ToElement(), e, reg);
+        } else if (!strcmp(pParent->Value(), "subject")) {
+            e = REG_CATEGORIES;
+            get_attribute(pParent->ToElement(), e, reg);
+        }
     }
 
     for (pChild = pParent->FirstChild(); pChild != 0;
@@ -151,21 +144,21 @@ static int process_node(TiXmlNode *pParent, RrnReg *reg) {
 }
 
 RrnReg *rrn_omf_parse_file(char *path) {
-    bool loadok;
+    tinyxml2::XMLError loadok;
     RrnReg *reg;
-    TiXmlDocument doc(path);
+    tinyxml2::XMLDocument doc;
 
     reg = rrn_reg_new();
 
-    loadok = doc.LoadFile(TIXML_ENCODING_UTF8);
+    loadok = doc.LoadFile(path);
 
-    if (!loadok) {
+    if (loadok != tinyxml2::XML_SUCCESS) {
         fprintf(stderr, "ERROR: Cannot parse %s.  Is it valid?\n", path);
         rrn_reg_free(reg);
         return NULL;
     }
 
-    TiXmlNode *pParent = doc.FirstChildElement();
+    tinyxml2::XMLNode *pParent = doc.FirstChildElement();
 
     if (process_node(pParent, reg) != 0) {
         rrn_reg_free(reg);
