@@ -22,27 +22,42 @@
 #ifndef __RARIAN_UTILS_H
 #define __RARIAN_UTILS_H
 
+#include <stdio.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
- /* A collection of useful functions that have no real place
-  * anywhere else
-  */
+#ifndef FALSE
+#define FALSE 0
+#define TRUE !FALSE
+#endif
 
- /* The string functions are shamelessly cribbed from glib,
-  * changing their names to fit into rarian */
+/* A collection of useful functions that have no real place
+ * anywhere else
+ */
+
+/* The string functions are shamelessly cribbed from glib,
+ * changing their names to fit into rarian */
 
 /* removes leading spaces */
-char*                rrn_chug        (char        *string);
+char *rrn_chug(char *string);
 /* removes trailing spaces */
-char*                rrn_chomp       (char        *string);
+char *rrn_chomp(char *string);
 
-  char *               rrn_strndup     (char      *string, int len);
+char *rrn_strndup(char *string, int len);
 
+#define rrn_strip(string) rrn_chomp(rrn_chug(string))
 
-#define rrn_strip( string )    rrn_chomp (rrn_chug (string))
+int rrn_read_line(char **buf, size_t *buf_len, FILE *file);
 
+char *rrn_strconcat(const char *first, ...);
+
+size_t rrn_str_count(const char *in, char c);
+
+char **rrn_str_split(const char *in, char c);
+
+void rrn_freev(char **in);
 
 #ifdef __cplusplus
 }
