@@ -20,7 +20,7 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "tinyxml.h"
+#include "tinyxml2.h"
 #include <stdio.h>
 
 static bool am_parsing = false;
@@ -36,36 +36,30 @@ void print_usage(char *proc_name) {
     exit(0);
 }
 
-void get_attribute(TiXmlElement *elem, char *new_url) {
-    TiXmlAttribute *pAttrib = elem->FirstAttribute();
+void get_attribute(tinyxml2::XMLElement *elem, char *new_url) {
+    const tinyxml2::XMLAttribute *pAttrib = elem->FirstAttribute();
     if (strcmp(pAttrib->Value(), "")) {
         elem->SetAttribute("url", new_url);
     }
 }
 
-void process_node(TiXmlNode *pParent, char *new_url) {
-    TiXmlNode *pChild;
-    TiXmlText *pText;
-    int t = pParent->Type();
+void process_node(tinyxml2::XMLNode *pParent, char *new_url) {
+    tinyxml2::XMLNode *pChild;
+    tinyxml2::XMLText *pText;
     int num;
 
-    switch (t) {
-        case TiXmlNode::TINYXML_DOCUMENT:
-            break;
-
-        case TiXmlNode::TINYXML_ELEMENT:
-            if (!strcmp(pParent->Value(), "omf")) {
-                am_parsing = true;
-            } else if (!am_parsing) {
-                printf("ERROR: Does not appear to be a valid OMF file.  "
-                       "Aborting\n");
-                exit(6);
-            }
-            if (!strcmp(pParent->Value(), "identifier")) {
-                get_attribute(pParent->ToElement(), new_url);
-            }
-        default:
-            break;
+    if ((pParent->ToDocument() == nullptr) &&
+        (pParent->ToElement() != nullptr)) {
+        if (!strcmp(pParent->Value(), "omf")) {
+            am_parsing = true;
+        } else if (!am_parsing) {
+            printf("ERROR: Does not appear to be a valid OMF file.  "
+                   "Aborting\n");
+            exit(6);
+        }
+        if (!strcmp(pParent->Value(), "identifier")) {
+            get_attribute(pParent->ToElement(), new_url);
+        }
     }
 
     for (pChild = pParent->FirstChild(); pChild != 0;
@@ -111,18 +105,18 @@ int main(int argc, char *argv[]) {
 
     char *new_url = process_new_url(argv[1 + skip]);
 
-    bool loadok;
+    tinyxml2::XMLError loadok;
 
-    TiXmlDocument doc(argv[2 + skip]);
-    loadok = doc.LoadFile(TIXML_ENCODING_UTF8);
+    tinyxml2::XMLDocument doc;
+    loadok = doc.LoadFile(argv[2 + skip]);
 
-    if (!loadok) {
+    if (loadok != tinyxml2::XML_SUCCESS) {
         fprintf(stderr, "ERROR: Cannot parse %s.  Is it valid?\n",
                 argv[2 + skip]);
         exit(2);
     }
 
-    TiXmlNode *pParent = doc.FirstChild();
+    tinyxml2::XMLNode *pParent = doc.FirstChild();
 
     process_node(pParent, new_url);
 
